@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2015-2020 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -22,22 +22,30 @@
 
 #include <QObject>
 #include "messageviewer_export.h"
-namespace MessageViewer
-{
+#include <PimCommon/PluginUtil>
+namespace MessageViewer {
 class HeaderStylePlugin;
 class HeaderStylePluginManagerPrivate;
+/**
+ * @brief The HeaderStylePluginManager class
+ * @author Laurent Montel <montel@kde.org>
+ */
 class MESSAGEVIEWER_EXPORT HeaderStylePluginManager : public QObject
 {
     Q_OBJECT
 public:
     static HeaderStylePluginManager *self();
 
-    explicit HeaderStylePluginManager(QObject *parent = Q_NULLPTR);
+    explicit HeaderStylePluginManager(QObject *parent = nullptr);
     ~HeaderStylePluginManager();
 
-    QVector<MessageViewer::HeaderStylePlugin *> pluginsList() const;
-    QStringList pluginListName() const;
+    Q_REQUIRED_RESULT QVector<MessageViewer::HeaderStylePlugin *> pluginsList() const;
+    Q_REQUIRED_RESULT QStringList pluginListName() const;
 
+    Q_REQUIRED_RESULT QVector<PimCommon::PluginUtilData> pluginsDataList() const;
+    Q_REQUIRED_RESULT QString configPrefixSettingKey() const;
+    Q_REQUIRED_RESULT QString configGroupName() const;
+    Q_REQUIRED_RESULT MessageViewer::HeaderStylePlugin *pluginFromIdentifier(const QString &id);
 private:
     HeaderStylePluginManagerPrivate *const d;
 };
